@@ -6,13 +6,18 @@
 
 using namespace frc2;
 
-ProxyScheduleCommand::ProxyScheduleCommand(wpi::ArrayRef<std::shared_ptr<Command>> toSchedule) {
+ProxyScheduleCommand::ProxyScheduleCommand(
+    wpi::span<std::shared_ptr<Command>> toSchedule) {
   SetInsert(m_toSchedule, toSchedule);
 }
 
+ProxyScheduleCommand::ProxyScheduleCommand(std::shared_ptr<Command> toSchedule) {
+  SetInsert(m_toSchedule, {&toSchedule, 1});
+}
+
 void ProxyScheduleCommand::Initialize() {
   for (auto command : m_toSchedule) {
-    command->Schedule();
+    Command_Schedule(command);
   }
 }
 
