@@ -7,6 +7,7 @@
 #include <initializer_list>
 #include <memory>
 
+#include <frc/Timer.h>
 #include <frc/controller/HolonomicDriveController.h>
 #include <frc/controller/PIDController.h>
 #include <frc/controller/ProfiledPIDController.h>
@@ -20,19 +21,18 @@
 #include <units/length.h>
 #include <units/velocity.h>
 #include <units/voltage.h>
-#include <wpi/ArrayRef.h>
+#include <wpi/span.h>
 
 #include "CommandBase.h"
 #include "CommandHelper.h"
-#include "frc2/Timer.h"
 
 #pragma once
 
 namespace frc2 {
 /**
- * A command that uses two PID controllers ({@link PIDController}) and a
- * ProfiledPIDController ({@link ProfiledPIDController}) to follow a trajectory
- * {@link Trajectory} with a mecanum drive.
+ * A command that uses two PID controllers (PIDController) and a profiled PID
+ * controller (ProfiledPIDController) to follow a trajectory (Trajectory) with a
+ * mecanum drive.
  *
  * <p>The command handles trajectory-following,
  * Velocity PID calculations, and feedforwards internally. This
@@ -204,7 +204,7 @@ class MecanumControllerCommand
       std::function<void(units::volt_t, units::volt_t, units::volt_t,
                          units::volt_t)>
           output,
-      wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements = {});
+      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Constructs a new MecanumControllerCommand that when executed will follow
@@ -257,7 +257,7 @@ class MecanumControllerCommand
       std::function<void(units::volt_t, units::volt_t, units::volt_t,
                          units::volt_t)>
           output,
-      wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements = {});
+      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Constructs a new MecanumControllerCommand that when executed will follow
@@ -373,7 +373,7 @@ class MecanumControllerCommand
                          units::meters_per_second_t,
                          units::meters_per_second_t)>
           output,
-      wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements = {});
+      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
 
   /**
    * Constructs a new MecanumControllerCommand that when executed will follow
@@ -413,7 +413,7 @@ class MecanumControllerCommand
                          units::meters_per_second_t,
                          units::meters_per_second_t)>
           output,
-      wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements = {});
+      wpi::span<std::shared_ptr<Subsystem>> requirements = {});
 
   void Initialize() override;
 
@@ -444,7 +444,7 @@ class MecanumControllerCommand
       m_outputVolts;
 
   bool m_usePID;
-  frc2::Timer m_timer;
+  frc::Timer m_timer;
   frc::MecanumDriveWheelSpeeds m_prevSpeeds;
   units::second_t m_prevTime;
 };
